pygac
=====

[![Build](https://github.com/pytroll/pygac/actions/workflows/ci.yaml/badge.svg)](https://github.com/pytroll/pygac/actions/workflows/ci.yaml)
[![Coverage](https://codecov.io/gh/pytroll/pygac/branch/main/graph/badge.svg?token=DQMgf2LxuM)](https://codecov.io/gh/pytroll/pygac)
[![DOI](https://zenodo.org/badge/DOI/10.5281/zenodo.5832775.svg)](https://doi.org/10.5281/zenodo.5832775)


Pygac is a Python package to read, calibrate and navigate data from the AVHRR 
instrument onboard NOAA and MetOp satellites in GAC and LAC format.

The documentation is available at https://pygac.readthedocs.io/.
